@@ -43,7 +43,7 @@ class NsmcCorpus:
                 continue
             _, review_sentence, sentiment = line
             sentiment = "긍정" if sentiment == "1" else "부정"
-            text = sentiment + ": " + review_sentence
+            text = sentiment + " " + review_sentence
             examples.append(GenerationExample(text=text))
         return examples
 
