@@ -1,6 +1,5 @@
 import os
 import sys
-import json
 import tqdm
 import logging
 import requests
@@ -20,6 +19,16 @@ REMOTE_DATA_MAP = {
             "fname": "val.txt",
         },
     },
+    "klue-nli": {
+        "train": {
+            "googledrive_file_id": "18LhrHaPEW0VITMPfnwKXJ6bNuklBdi4U",
+            "fname": "klue_nli_train.json",
+        },
+        "val": {
+            "googledrive_file_id": "1UKIDAFOFuDSah7A66FZXSA8XUWUHhBAd",
+            "fname": "klue_nli_dev.json",
+        }
+    },
     "ner": {
         "train": {
             "googledrive_file_id": "1RP764owqs1kZeHcjFnCX7zXt2EcjGY1i",
